#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-web
version:              1.52
visibility:           public
id:                   hledger-web-1.52-8MCPZMRDb3cCHJkdruyhA1
key:                  hledger-web-1.52-8MCPZMRDb3cCHJkdruyhA1
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Web user interface for the hledger accounting system
description:
    A simple web user interface for the hledger accounting system,
    providing a more modern UI than the command-line or terminal interfaces.
    It can be used as a local single-user UI, or as a multi-user UI for
    viewing\/adding\/editing on the web.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance
abi:                  0684268be4b29e106e79affa6b7700bc
exposed:              True
exposed-modules:
    Hledger.Web Hledger.Web.App Hledger.Web.Application
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Main Hledger.Web.Settings
    Hledger.Web.Settings.StaticFiles Hledger.Web.Test
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common

hidden-modules:       Paths_hledger_web
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-web
hs-libraries:         HShledger-web-1.52-8MCPZMRDb3cCHJkdruyhA1
depends:
    Decimal-0.5.2-6GEQ8TrZBfdBsnW9QhT4SP
    aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY base-4.18.2.1
    base64-1.0-DqNSf3tHM4CArNLOpsgo1t
    blaze-html-0.9.2.0-2DuDW300GIs3GBNnqFMort
    blaze-markup-0.8.3.0-5HaQctUz2WgK7Wu4GhbGjR bytestring-0.11.5.3
    case-insensitive-1.2.1.0-IhPAKZHiECkGPRzzh8aBPd
    clientsession-0.9.3.0-7BbI11N1yz65irTM1BEyO1
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-ASxyqnNN5o6JNEZENxLkTo
    conduit-extra-1.3.8-4ND3rHkWnMCxT3MRqBhox containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-GG4oQL1Pbvk2YReVs3ucdi
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    githash-0.1.6.3-GUPPgRbB6OuEbmCcGv8KZB
    hjsmin-0.2.1-JglozqpkQKe5P9KIMctgQI
    hledger-1.52-EKTETgo92WqMuzwLaxgHM
    hledger-lib-1.52-7wWrvbhRox2B6Nht9MUqrA
    hspec-2.11.5-LAcpW14V5x92DJUdeVnlb
    http-client-0.7.19-IEWR3rTgLbz23aQ2c2Laos
    http-conduit-2.3.9.1-EXT0Jnfj3v0DhzxQQnnhUg
    http-types-0.12.4-YzImfxD6FM4aZnfovaubB
    megaparsec-9.7.0-ANIQXwq4KPSJ1jjmaOZNxr mtl-2.3.1
    network-3.1.4.0-10rvNinchMB4AwxOArhT4I
    safe-0.3.21-CJwI1nXd4mu5AecalHl564
    shakespeare-2.1.7.1-9DZXdweLP7KD65LeX78D4J
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BnGVCTqWzO94VHR7bIvixK
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    wai-3.2.4-1wByteS70fS6Q8pU8g38GM
    wai-cors-0.2.7-DVZOCjfcamPEdrTotOuaPN
    wai-extra-3.1.18-E9Gl5wPlqQJ3aGmuoOaQsH
    wai-handler-launch-3.0.3.1-IG4SplsUG528OZavZHm0S8
    warp-3.4.0-IGSnxQlK2PaAQoRBXNBvLf
    yaml-0.11.11.2-3uuTzm3w0KboX5NWuQdx3
    yesod-1.6.2.1-1cmmaowKbhfFFd1M31hXFP
    yesod-core-1.6.27.1-9spqSNfZhIB66UYQfSguxx
    yesod-form-1.7.9.2-E5ymh4Xjpg2KhWEPukxznp
    yesod-static-1.6.1.2-Cly04kPxGM589M7F42Y5dO
    yesod-test-1.6.23-HJXw6jh4B1f73RaJnpWX4N

haddock-interfaces:   /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html:         /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

